Class: Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1RestoreDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta2/classes.rb,
lib/google/apis/firestore_v1beta2/representations.rb,
lib/google/apis/firestore_v1beta2/representations.rb

Overview

Metadata for the long-running operation from the RestoreDatabase request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseMetadata

Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseMetadata.



286
287
288
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

The name of the backup restoring from. Corresponds to the JSON property backup

Returns:

  • (String)


258
259
260
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 258

def backup
  @backup
end

#databaseString

The name of the database being restored to. Corresponds to the JSON property database

Returns:

  • (String)


263
264
265
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 263

def database
  @database
end

#end_timeString

The time the restore finished, unset for ongoing restores. Corresponds to the JSON property endTime

Returns:

  • (String)


268
269
270
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 268

def end_time
  @end_time
end

#operation_stateString

The operation state of the restore. Corresponds to the JSON property operationState

Returns:

  • (String)


273
274
275
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 273

def operation_state
  @operation_state
end

#progress_percentageGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressPercentage



279
280
281
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 279

def progress_percentage
  @progress_percentage
end

#start_timeString

The time the restore was started. Corresponds to the JSON property startTime

Returns:

  • (String)


284
285
286
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 284

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



291
292
293
294
295
296
297
298
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 291

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @database = args[:database] if args.key?(:database)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage)
  @start_time = args[:start_time] if args.key?(:start_time)
end