Class: Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2ExportDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta2/classes.rb,
lib/google/apis/firestore_v1beta2/representations.rb,
lib/google/apis/firestore_v1beta2/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. ExportDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1beta2ExportDocumentsMetadata

Returns a new instance of GoogleFirestoreAdminV1beta2ExportDocumentsMetadata.



376
377
378
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

Which collection ids are being exported. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


341
342
343
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 341

def collection_ids
  @collection_ids
end

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 347

def end_time
  @end_time
end

#operation_stateString

The state of the export operation. Corresponds to the JSON property operationState

Returns:

  • (String)


352
353
354
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 352

def operation_state
  @operation_state
end

#output_uri_prefixString

Where the entities are being exported to. Corresponds to the JSON property outputUriPrefix

Returns:

  • (String)


357
358
359
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 357

def output_uri_prefix
  @output_uri_prefix
end

#progress_bytesGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



363
364
365
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 363

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



369
370
371
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 369

def progress_documents
  @progress_documents
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


374
375
376
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 374

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



381
382
383
384
385
386
387
388
389
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 381

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @output_uri_prefix = args[:output_uri_prefix] if args.key?(:output_uri_prefix)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @start_time = args[:start_time] if args.key?(:start_time)
end