Class: Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2FieldOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2FieldOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta2/classes.rb,
lib/google/apis/firestore_v1beta2/representations.rb,
lib/google/apis/firestore_v1beta2/representations.rb
Overview
Metadata for google.longrunning.Operation results from FirestoreAdmin. UpdateField.
Instance Attribute Summary collapse
-
#bytes_progress ⇒ Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress
Describes the progress of the operation.
-
#document_progress ⇒ Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress
Describes the progress of the operation.
-
#end_time ⇒ String
The time this operation completed.
-
#field ⇒ String
The field resource that this operation is acting on.
-
#index_config_deltas ⇒ Array<Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2IndexConfigDelta>
A list of IndexConfigDelta, which describe the intent of this operation.
-
#start_time ⇒ String
The time this operation started.
-
#state ⇒ String
The state of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta2FieldOperationMetadata
constructor
A new instance of GoogleFirestoreAdminV1beta2FieldOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta2FieldOperationMetadata
Returns a new instance of GoogleFirestoreAdminV1beta2FieldOperationMetadata.
532 533 534 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bytes_progress ⇒ Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property bytesProgress
496 497 498 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 496 def bytes_progress @bytes_progress end |
#document_progress ⇒ Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property documentProgress
502 503 504 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 502 def document_progress @document_progress end |
#end_time ⇒ String
The time this operation completed. Will be unset if operation still in
progress.
Corresponds to the JSON property endTime
508 509 510 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 508 def end_time @end_time end |
#field ⇒ String
The field resource that this operation is acting on. For example: projects/
project_id/databases/database_id/collectionGroups/collection_id/fields/
field_path`
Corresponds to the JSON propertyfield`
515 516 517 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 515 def field @field end |
#index_config_deltas ⇒ Array<Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2IndexConfigDelta>
A list of IndexConfigDelta, which describe the intent of this operation.
Corresponds to the JSON property indexConfigDeltas
520 521 522 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 520 def index_config_deltas @index_config_deltas end |
#start_time ⇒ String
The time this operation started.
Corresponds to the JSON property startTime
525 526 527 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 525 def start_time @start_time end |
#state ⇒ String
The state of the operation.
Corresponds to the JSON property state
530 531 532 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 530 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
537 538 539 540 541 542 543 544 545 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 537 def update!(**args) @bytes_progress = args[:bytes_progress] if args.key?(:bytes_progress) @document_progress = args[:document_progress] if args.key?(:document_progress) @end_time = args[:end_time] if args.key?(:end_time) @field = args[:field] if args.key?(:field) @index_config_deltas = args[:index_config_deltas] if args.key?(:index_config_deltas) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |