Class: Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2ImportDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta2/classes.rb,
lib/google/apis/firestore_v1beta2/representations.rb,
lib/google/apis/firestore_v1beta2/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. ImportDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1beta2ImportDocumentsMetadata

Returns a new instance of GoogleFirestoreAdminV1beta2ImportDocumentsMetadata.



591
592
593
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

Which collection ids are being imported. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


556
557
558
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 556

def collection_ids
  @collection_ids
end

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


562
563
564
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 562

def end_time
  @end_time
end

#input_uri_prefixString

The location of the documents being imported. Corresponds to the JSON property inputUriPrefix

Returns:

  • (String)


567
568
569
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 567

def input_uri_prefix
  @input_uri_prefix
end

#operation_stateString

The state of the import operation. Corresponds to the JSON property operationState

Returns:

  • (String)


572
573
574
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 572

def operation_state
  @operation_state
end

#progress_bytesGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



578
579
580
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 578

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



584
585
586
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 584

def progress_documents
  @progress_documents
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


589
590
591
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 589

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



596
597
598
599
600
601
602
603
604
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 596

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @end_time = args[:end_time] if args.key?(:end_time)
  @input_uri_prefix = args[:input_uri_prefix] if args.key?(:input_uri_prefix)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @start_time = args[:start_time] if args.key?(:start_time)
end