Class: Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2IndexOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta2/classes.rb,
lib/google/apis/firestore_v1beta2/representations.rb,
lib/google/apis/firestore_v1beta2/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. CreateIndex.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1beta2IndexOperationMetadata

Returns a new instance of GoogleFirestoreAdminV1beta2IndexOperationMetadata.



835
836
837
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


804
805
806
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 804

def end_time
  @end_time
end

#indexString

The index resource that this operation is acting on. For example: projects/ project_id/databases/database_id/collectionGroups/collection_id/indexes/ index_id` Corresponds to the JSON propertyindex`

Returns:

  • (String)


811
812
813
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 811

def index
  @index
end

#progress_bytesGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



817
818
819
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 817

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



823
824
825
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 823

def progress_documents
  @progress_documents
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


828
829
830
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 828

def start_time
  @start_time
end

#stateString

The state of the operation. Corresponds to the JSON property state

Returns:

  • (String)


833
834
835
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 833

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



840
841
842
843
844
845
846
847
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 840

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @index = args[:index] if args.key?(:index)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end