Class: Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2ExportDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta2/classes.rb,
lib/google/apis/firestore_v1beta2/representations.rb,
lib/google/apis/firestore_v1beta2/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. ExportDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1beta2ExportDocumentsMetadata

Returns a new instance of GoogleFirestoreAdminV1beta2ExportDocumentsMetadata.



357
358
359
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

Which collection ids are being exported. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


322
323
324
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 322

def collection_ids
  @collection_ids
end

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


328
329
330
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 328

def end_time
  @end_time
end

#operation_stateString

The state of the export operation. Corresponds to the JSON property operationState

Returns:

  • (String)


333
334
335
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 333

def operation_state
  @operation_state
end

#output_uri_prefixString

Where the entities are being exported to. Corresponds to the JSON property outputUriPrefix

Returns:

  • (String)


338
339
340
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 338

def output_uri_prefix
  @output_uri_prefix
end

#progress_bytesGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



344
345
346
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 344

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



350
351
352
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 350

def progress_documents
  @progress_documents
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


355
356
357
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 355

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



362
363
364
365
366
367
368
369
370
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 362

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @output_uri_prefix = args[:output_uri_prefix] if args.key?(:output_uri_prefix)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @start_time = args[:start_time] if args.key?(:start_time)
end