Class: Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2FieldOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2FieldOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta2/classes.rb,
lib/google/apis/firestore_v1beta2/representations.rb,
lib/google/apis/firestore_v1beta2/representations.rb
Overview
Metadata for google.longrunning.Operation results from FirestoreAdmin. UpdateField.
Instance Attribute Summary collapse
-
#bytes_progress ⇒ Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress
Describes the progress of the operation.
-
#document_progress ⇒ Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress
Describes the progress of the operation.
-
#end_time ⇒ String
The time this operation completed.
-
#field ⇒ String
The field resource that this operation is acting on.
-
#index_config_deltas ⇒ Array<Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2IndexConfigDelta>
A list of IndexConfigDelta, which describe the intent of this operation.
-
#start_time ⇒ String
The time this operation started.
-
#state ⇒ String
The state of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta2FieldOperationMetadata
constructor
A new instance of GoogleFirestoreAdminV1beta2FieldOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta2FieldOperationMetadata
Returns a new instance of GoogleFirestoreAdminV1beta2FieldOperationMetadata.
513 514 515 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bytes_progress ⇒ Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property bytesProgress
477 478 479 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 477 def bytes_progress @bytes_progress end |
#document_progress ⇒ Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property documentProgress
483 484 485 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 483 def document_progress @document_progress end |
#end_time ⇒ String
The time this operation completed. Will be unset if operation still in
progress.
Corresponds to the JSON property endTime
489 490 491 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 489 def end_time @end_time end |
#field ⇒ String
The field resource that this operation is acting on. For example: projects/
project_id/databases/database_id/collectionGroups/collection_id/fields/
field_path`
Corresponds to the JSON propertyfield`
496 497 498 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 496 def field @field end |
#index_config_deltas ⇒ Array<Google::Apis::FirestoreV1beta2::GoogleFirestoreAdminV1beta2IndexConfigDelta>
A list of IndexConfigDelta, which describe the intent of this operation.
Corresponds to the JSON property indexConfigDeltas
501 502 503 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 501 def index_config_deltas @index_config_deltas end |
#start_time ⇒ String
The time this operation started.
Corresponds to the JSON property startTime
506 507 508 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 506 def start_time @start_time end |
#state ⇒ String
The state of the operation.
Corresponds to the JSON property state
511 512 513 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 511 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
518 519 520 521 522 523 524 525 526 |
# File 'lib/google/apis/firestore_v1beta2/classes.rb', line 518 def update!(**args) @bytes_progress = args[:bytes_progress] if args.key?(:bytes_progress) @document_progress = args[:document_progress] if args.key?(:document_progress) @end_time = args[:end_time] if args.key?(:end_time) @field = args[:field] if args.key?(:field) @index_config_deltas = args[:index_config_deltas] if args.key?(:index_config_deltas) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |